@@ -120,6 +120,9 @@ sub delete {
 
 sub update {
     my ($self, $table, $param, @opts) = @_;
+    if (ref $param eq 'HASH') {
+        $param = [%$param];
+    }
     $param = $self->_deflate_param($table, $param);
     my ($sql, @binds) = $self->maker->update($table, $param, @opts);
     $self->dbh->query($sql, @binds);
@@ -237,7 +240,7 @@ DBIx::Otogiri - Core of Otogiri
     my $hash = $db->no_row_class->single(book => {id => 1}); # $hash is HASH reference.
     say $hash->{title}; # => say book title.
 
-    $db->update(book => [author => 'oreore'], {author => 'me'});
+    $db->update(book => {author => 'oreore'}, {author => 'me'});
     
     $db->delete(book => {author => 'me'});
     
@@ -376,7 +379,7 @@ Unset row class name. If you unset row class name, you can receive result as HAS
 
 =head2 update
 
-    $db->update($table_name => [update_col_1 => $new_value_1, ...], $conditions_in_hashref);
+    $db->update($table_name => {update_col_1 => $new_value_1, ...}, $conditions_in_hashref);
 
 Update rows that matched to $conditions_in_hashref.
 
